@@ -165,7 +165,7 @@ static void __eap_tls_common_state_reset(struct eap_state *eap)
 	 *
 	 * Drop the cache even if we have no indication that the
 	 * method failed but it just didn't succeed, to handle cases like
-	 * the server getting stuck and a timout occuring at a higher
+	 * the server getting stuck and a timeout occurring at a higher
 	 * layer.  The risk is that we may occasionally flush the session
 	 * data when there was only a momentary radio issue, invalid
 	 * phase2 credentials or decision to abort.  Those are not hot
@@ -500,10 +500,9 @@ static int eap_tls_init_request_assembly(struct eap_state *eap,
 	tls_msg_len = l_get_be32(pkt);
 	len -= 4;
 
-	if (!tls_msg_len || tls_msg_len > EAP_TLS_PDU_MAX_LEN) {
-		l_warn("%s: Fragmented pkt size is outside of allowed"
-				" boundaries [1, %u]", eap_get_method_name(eap),
-							EAP_TLS_PDU_MAX_LEN);
+	if (tls_msg_len > EAP_TLS_PDU_MAX_LEN) {
+		l_warn("%s: Fragmented pkt size is larger than %u.",
+				eap_get_method_name(eap), EAP_TLS_PDU_MAX_LEN);
 
 		return -EINVAL;
 	}
