@@ -20,6 +20,8 @@
  *
  */
 
+#include "src/defs.h"
+
 #define SETTINGS "Settings"
 #define NET_HIDDEN SETTINGS, "Hidden"
 #define NET_AUTOCONNECT SETTINGS, "AutoConnect"
@@ -27,6 +29,7 @@
 #define NET_ADDRESS_OVERRIDE SETTINGS, "AddressOverride"
 #define NET_TRANSITION_DISABLE SETTINGS, "TransitionDisable"
 #define NET_TRANSITION_DISABLE_MODES SETTINGS, "DisabledTransitionModes"
+#define NET_USE_DEFAULT_ECC_GROUP SETTINGS, "UseDefaultEccGroup"
 
 enum security;
 struct scan_freq_set;
@@ -38,6 +41,12 @@ enum known_networks_event {
 	KNOWN_NETWORKS_EVENT_UPDATED,
 };
 
+enum known_network_ecc_group {
+	KNOWN_NETWORK_ECC_GROUP_AUTO = 0,
+	KNOWN_NETWORK_ECC_GROUP_DEFAULT,
+	KNOWN_NETWORK_ECC_GROUP_MOST_SECURE,
+};
+
 struct network_info_ops {
 	struct l_settings *(*open)(struct network_info *info);
 	int (*touch)(struct network_info *info);
@@ -72,11 +81,12 @@ struct network_config {
 	uint8_t sta_addr[6];
 	bool have_transition_disable : 1;
 	uint8_t transition_disable;
+	enum known_network_ecc_group ecc_group;
 };
 
 struct network_info {
 	const struct network_info_ops *ops;
-	char ssid[33];
+	char ssid[SSID_MAX_SIZE + 1];
 	enum security type;
 	struct l_queue *known_frequencies;
 	int seen_count;			/* Ref count for network.info */
