@@ -142,7 +142,8 @@ static const struct {
 	{ NL80211_CMD_GET_MPP,			"Get Mesh Proxy Path"	},
 	{ NL80211_CMD_JOIN_OCB,			"Join OCB Network"	},
 	{ NL80211_CMD_LEAVE_OCB,		"Leave OCB Network"	},
-	{ NL80211_CMD_CH_SWITCH_STARTED_NOTIFY, "Channel Switch Notify"	},
+	{ NL80211_CMD_CH_SWITCH_STARTED_NOTIFY,
+					"Channel Switch Started Notify"},
 	{ NL80211_CMD_TDLS_CHANNEL_SWITCH,	"TDLS Channel Switch"	},
 	{ NL80211_CMD_TDLS_CANCEL_CHANNEL_SWITCH,
 						"Cancel TLDS Channel Switch" },
